import React, { useState } from 'react';
import PropTypes from 'prop-types';
import { Text } from '../../atoms/text/Text';
import { useDisclosure } from '../../helpers/useDisclosure';

const propTypes = {
  className: PropTypes.string,
  confirmPhrase: PropTypes.string,
  onDelete: PropTypes.func,
};

const defaultProps = {
  className: 'sui-a-form-control sui-h-mb-md',
  confirmPhrase: '',
  onDelete: () => {},
};

export const ModalInput = ({
  className, confirmPhrase, onDelete,
}) => {
  const [inputValue, setInputValue] = useState('');
  const { close } = useDisclosure(false);

  const handleInputChange = (e) => {
    const { value } = e.target;
    setInputValue(value);
  };

  return (
    <>
      <Text className="sui-h-mv-md">{`Type "${confirmPhrase}" to confirm:`}</Text>
      <input className={className} value={inputValue} onChange={handleInputChange} />
      <Text color="danger" className="sui-h-mv-md">This operation cannot be undone.</Text>
      <div className="sui-g-grid">
        <div className="sui-g-grid__item as--pull">
          <button type="button" className="sui-a-button" onClose={close}>
            Cancel
          </button>
        </div>
        <div className="sui-g-grid__item as--push">
          <button type="button" className="sui-a-button as--danger" disabled={inputValue !== confirmPhrase} onClick={onDelete}>
            Delete
          </button>
        </div>
      </div>
    </>
  );
};

ModalInput.propTypes = propTypes;
ModalInput.defaultProps = defaultProps;
